from setuptools import setup, find_packages

setup(
    name='sm-search-connector-poc-interface',
    version='0.2.1',
    description='A SageMaker Search Connector Interface for POC',
    author='mitulshr',
    author_email='your.email@example.com',
    packages=find_packages(),
    install_requires=[
        # List your package's dependencies here
    ],
)
